pub trait EvalWithDefault {
// Required method
fn explicit_yes_and_no(&self) -> (bool, bool);
// Provided method
fn eval_with_default(&self, default: bool) -> bool { ... }
}Expand description
Evaluate a set of explicit yes and explicit no boolean values to a single boolean, given a default yes or no.